#[repr(transparent)]pub struct AVCaptureCenterStageControlMode(pub NSInteger);Available on crate feature
AVCaptureDevice only.Expand description
Constants indicating the current Center Stage control mode.
Indicates that the application is unaware of the Center Stage feature. Its enablement is entirely under user control in Control Center.
Indicates that the application controls the Center Stage feature, disallowing input from the user in Control Center.
Indicates that both the user and application cooperatively share control of the Center Stage feature.
See also Apple’s documentation
Tuple Fields
0: NSIntegerImplementations