AVCaptureDataOutputSynchronizerDelegate

Trait AVCaptureDataOutputSynchronizerDelegate 

pub unsafe trait AVCaptureDataOutputSynchronizerDelegate: NSObjectProtocol {
    // Provided method
    unsafe fn dataOutputSynchronizer_didOutputSynchronizedDataCollection(
        &self,
        synchronizer: &AVCaptureDataOutputSynchronizer,
        synchronized_data_collection: &AVCaptureSynchronizedDataCollection,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature AVCaptureDataOutputSynchronizer only.
Provided Methods

unsafe fn dataOutputSynchronizer_didOutputSynchronizedDataCollection( &self, synchronizer: &AVCaptureDataOutputSynchronizer, synchronized_data_collection: &AVCaptureSynchronizedDataCollection, )
where Self: Sized + Message,

Called when an AVCaptureDataOutputSynchronizer instance outputs synchronized data from one or more data outputs.

Parameter synchronizer: The AVCaptureDataOutputSynchronizer instance delivering synchronized data.

Parameter synchronizedDataCollection: A collection of synchronized data objects indexed by data output.

The synchronized data collection only contains synchronized data for capture outputs with synchronized data ready.