pub unsafe trait AVCaptureSessionControlsDelegate: NSObjectProtocol {
// Provided methods
unsafe fn sessionControlsDidBecomeActive(&self, session: &AVCaptureSession)
where Self: Sized + Message { ... }
unsafe fn sessionControlsWillEnterFullscreenAppearance(
&self,
session: &AVCaptureSession,
)
where Self: Sized + Message { ... }
unsafe fn sessionControlsWillExitFullscreenAppearance(
&self,
session: &AVCaptureSession,
)
where Self: Sized + Message { ... }
unsafe fn sessionControlsDidBecomeInactive(
&self,
session: &AVCaptureSession,
)
where Self: Sized + Message { ... }
}AVCaptureSession only.Expand description
Defines an interface for delegates of AVCaptureSession to receive events about the session’s controls.
See also Apple’s documentation
Provided Methods
Sourceunsafe fn sessionControlsDidBecomeActive(&self, session: &AVCaptureSession)
unsafe fn sessionControlsDidBecomeActive(&self, session: &AVCaptureSession)
Called when the controls of an AVCaptureSession instance become active and are available for interaction.
Parameter session: The AVCaptureSession instance whose controls are active.
Delegates receive this message when the controls of an AVCaptureSession instance become active and are available for interaction.
Sourceunsafe fn sessionControlsWillEnterFullscreenAppearance(
&self,
session: &AVCaptureSession,
)
unsafe fn sessionControlsWillEnterFullscreenAppearance( &self, session: &AVCaptureSession, )
Called when the controls of an AVCaptureSession instance will enter a fullscreen appearance.
Parameter session: The AVCaptureSession instance whose controls will enter a fullscreen appearance.
When the controls enter a fullscreen appearance, applications are encouraged to hide portions of their user interface including zoom or exposure sliders and shutter buttons. Few on-screen elements should be visible so users can focus on the controls they are interacting with and view the camera preview unobstructed.
Sourceunsafe fn sessionControlsWillExitFullscreenAppearance(
&self,
session: &AVCaptureSession,
)
unsafe fn sessionControlsWillExitFullscreenAppearance( &self, session: &AVCaptureSession, )
Called when the controls of an AVCaptureSession instance will exit a fullscreen appearance.
Parameter session: The AVCaptureSession instance whose controls will exit a fullscreen appearance.
Delegates receive this message when the controls of an AVCaptureSession instance should resume showing portions of their user interface that were hidden in response to receiving -sessionControlsWillEnterFullscreenAppearance:. This message is sent before sessionControlsDidBecomeInactive:.
Sourceunsafe fn sessionControlsDidBecomeInactive(&self, session: &AVCaptureSession)
unsafe fn sessionControlsDidBecomeInactive(&self, session: &AVCaptureSession)
Called when the controls of an AVCaptureSession instance become inactive and are no longer available for interaction.
Parameter session: The AVCaptureSession instance whose controls are inactive.
Delegates receive this message when the controls of an AVCaptureSession instance become inactive and are no longer available for interaction.