AVCaptureTimecodeGeneratorDelegate

Trait AVCaptureTimecodeGeneratorDelegate 

pub unsafe trait AVCaptureTimecodeGeneratorDelegate: NSObjectProtocol {
    // Provided methods
    unsafe fn timecodeGenerator_didReceiveUpdate_fromSource(
        &self,
        generator: &AVCaptureTimecodeGenerator,
        timecode: AVCaptureTimecode,
        source: &AVCaptureTimecodeSource,
    )
       where Self: Sized + Message { ... }
    unsafe fn timecodeGenerator_transitionedToSynchronizationStatus_forSource(
        &self,
        generator: &AVCaptureTimecodeGenerator,
        synchronization_status: AVCaptureTimecodeGeneratorSynchronizationStatus,
        source: &AVCaptureTimecodeSource,
    )
       where Self: Sized + Message { ... }
    unsafe fn timecodeGenerator_didUpdateAvailableSources(
        &self,
        generator: &AVCaptureTimecodeGenerator,
        available_sources: &NSArray<AVCaptureTimecodeSource>,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature AVCaptureTimecodeGenerator only.
A protocol for receiving real-time timecode updates and error notifications from a timecode generator.

See also Apple’s documentation

Provided Methods

unsafe fn timecodeGenerator_didReceiveUpdate_fromSource( &self, generator: &AVCaptureTimecodeGenerator, timecode: AVCaptureTimecode, source: &AVCaptureTimecodeSource, )
where Self: Sized + Message,

Available on crate feature objc2-core-media only.

Notifies the delegate when new, unaligned timecodes are parsed from the specified source.

  • Parameter generator: The timecode generator providing the update.
  • Parameter timecode: The updated timecode data.
  • Parameter source: The source from which the timecode was received.
unsafe fn timecodeGenerator_transitionedToSynchronizationStatus_forSource( &self, generator: &AVCaptureTimecodeGenerator, synchronization_status: AVCaptureTimecodeGeneratorSynchronizationStatus, source: &AVCaptureTimecodeSource, )
where Self: Sized + Message,

Notifies the delegate when the synchronization status of a timecode source changes.

  • Parameter generator: The AVCaptureTimecodeGenerator instance providing the status update.
  • Parameter synchronizationStatus: The updated synchronization state.
  • Parameter source: The internal or external source to which the generator synchronizes.
unsafe fn timecodeGenerator_didUpdateAvailableSources( &self, generator: &AVCaptureTimecodeGenerator, available_sources: &NSArray<AVCaptureTimecodeSource>, )
where Self: Sized + Message,

Notifies the delegate when the list of available timecode synchronization sources is updated.

  • Parameter generator: The AVCaptureTimecodeGenerator instance providing the source list update.
  • Parameter availableSources: An array of AVCaptureTimecodeSource objects representing the available timecode synchronization sources.